Scanpy (https://scanpy.readthedocs.io/en/stable/api.html) stands for Single-Cell Analysis in Python. We use it for plotting UMAPs.

Since `scanpy` is a large package with many dependencies, we copied the umap part of their code so that we don't have to install `scanpy` itself.